@@ -58,10 +58,40 @@ runtime_format_string( const char * fmt_string )
 }
 #endif
 
+#if FMT_VERSION < 90000
+template< typename T >
+decltype(auto) streamed( T && v ) noexcept
+{
+	return std::forward<T>(v);
+}
+#else
+template< typename T >
+decltype(auto) streamed( T && v ) noexcept
+{
+	return fmt::streamed( std::forward<T>(v) );
+}
+#endif
+
 } /* namespace fmtlib_tools */
 
 } /* namespace restinio */
 
+/*
+ * NOTE: if RESTinio is used in project compiled with
+ * FMT_ENFORCE_COMPILE_STRING then a format_string for fmt::format
+ * and fmt::print function has to be specified via FMT_STRING macro.
+ *
+ * To cope with this a new macro RESTINIO_FMT_FORMAT_STRING(s) was
+ * introduced in v.0.6.17. It's expanded into FMT_STRING(s) if
+ * FMT_ENFORCE_COMPILE_STRING is set, otherwise it's just s.
+ */
+
+#if defined(FMT_ENFORCE_COMPILE_STRING)
+	#define RESTINIO_FMT_FORMAT_STRING(s) FMT_STRING(s)
+#else
+	#define RESTINIO_FMT_FORMAT_STRING(s) s
+#endif
+
 #if defined(__GNUG__) || defined(__clang__)
 
 #pragma GCC diagnostic pop
